@@ -1,14 +1,9 @@
 import mysql.connector
 import requests
+from . import api
 
-APIS = {
-  'prod': 'https://api-prod-wwueeaf46q-ey.a.run.app',
-  'test': 'https://api-test-wwueeaf46q-ey.a.run.app',
-  'dev':'http://127.0.0.1:5002'
-}
-
-def get_credentials(api_key, api='prod'):
-    response = requests.get(f"{APIS[api]}/api/db_credentials", headers={'key': api_key}).json()
+def get_credentials(api_key, schema='prod'):
+    response = requests.get(f"{api.get(schema)}/api/db_credentials", headers={'key': api_key}).json()
     if response['msg'] == 'success':
         return response['data']
     else:
@@ -16,8 +11,8 @@ def get_credentials(api_key, api='prod'):
         return None
 
 
-def get(api_key, api, buffered=True, dictionary=False):
-    credentials = get_credentials(api_key=api_key, api=api)
+def get(api_key, schema, buffered=True, dictionary=False):
+    credentials = get_credentials(api_key=api_key, schema=schema)
     if not credentials:
         return None, None
     cnx = mysql.connector.connect(
